##
##  mrtg.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         mrtg
Summary:      Multi Router Traffic Grapher
URL:          http://oss.oetiker.ch/mrtg/
Vendor:       Tobias Oetiker
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Monitoring
License:      GPL
Version:      2.17.10
Release:      20240209

#   list of sources
Source0:      http://oss.oetiker.ch/mrtg/pub/mrtg-%{version}.tar.gz
Source1:      mrtg.cfg
Source2:      rc.mrtg

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, perl, zlib, gd, png
PreReq:       OpenPKG, openpkg >= 20160101, perl, zlib, gd, png, snmp

%description
    The Multi Router Traffic Grapher (MRTG) is a tool to monitor the traffic
    load on network-links. MRTG generates HTML pages containing graphical
    images which provide a LIVE visual representation of this traffic.

%track
    prog mrtg = {
        version   = %{version}
        url       = http://oss.oetiker.ch/mrtg/pub/
        regex     = mrtg-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %{l_shtool} subst \
        -e 's;mrtg2";mrtg";g' \
        bin/*

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --with-gd=%{l_prefix} \
        --with-z=%{l_prefix} \
        --with-png=%{l_prefix}
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/mrtg \
        $RPM_BUILD_ROOT%{l_prefix}/var/mrtg \
        $RPM_BUILD_ROOT%{l_prefix}/web/mrtg
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.mrtg} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE mrtg.cfg} $RPM_BUILD_ROOT%{l_prefix}/etc/mrtg/
    mv  $RPM_BUILD_ROOT%{l_prefix}/lib/mrtg2 \
        $RPM_BUILD_ROOT%{l_prefix}/lib/mrtg
    mv  $RPM_BUILD_ROOT%{l_prefix}/share/mrtg2 \
        $RPM_BUILD_ROOT%{l_prefix}/share/mrtg
    mv -f $RPM_BUILD_ROOT%{l_prefix}/share/doc/mrtg2 \
        $RPM_BUILD_ROOT%{l_prefix}/share/mrtg/doc
    rmdir $RPM_BUILD_ROOT%{l_prefix}/share/doc
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/rateup >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/mrtg/mrtg.cfg' \
        '%doc %{l_prefix}/share/mrtg/doc/*'

%files -f files

%clean

